@@ -1,6 +1,6 @@
 from setuptools import setup, find_packages
 
-VERSION = '0.0.6' 
+VERSION = '0.0.7' 
 DESCRIPTION = 'short Mail sender'
 LONG_DESCRIPTION = 'Mail sender gmail smtp'
 
@@ -14,7 +14,7 @@ setup(
         description=DESCRIPTION,
         long_description=LONG_DESCRIPTION,
         packages=find_packages(),
-        scripts=['dokr'],
+        #scripts=['dokr'],
         install_requires=[], # add any additional packages that 
         # needs to be installed along with your package. Eg: 'caer'
         
